@@ -79,7 +79,7 @@ class Assignments(BrowserView):
             self.context.plone_utils.addPortalMessage(u'No members found', 'error')
             url = '%s/@@assignments?userid=%s&group=%s' % (self.context.absolute_url(),
                     self.request.get('userid', ''), self.request.get('group', ''))
-            return self.request.response(url)
+            return self.request.response.redirect(url)
 
         dashboards_updated = dict()
         site = getUtility(ISiteRoot)
